package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1OutputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.util.ASN1Dump;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.CRLDistPoint;
import cn.com.infosec.asn1.x509.CRLNumber;
import cn.com.infosec.asn1.x509.CertificateList;
import cn.com.infosec.asn1.x509.IssuingDistributionPoint;
import cn.com.infosec.asn1.x509.TBSCertList;
import cn.com.infosec.asn1.x509.Time;
import cn.com.infosec.asn1.x509.X509Extension;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.jce.provider.fastparser.DerUtil;
import cn.com.infosec.jce.provider.fastparser.FX509CRL;
import cn.com.infosec.jce.provider.fastparser.Item;
import cn.com.infosec.util.encoders.Hex;
import cn.com.infosec.x509.extension.X509ExtensionUtil;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.Principal;
import java.security.PublicKey;
import java.security.Signature;
import java.security.SignatureException;
import java.security.cert.CRLException;
import java.security.cert.Certificate;
import java.security.cert.X509CRL;
import java.security.cert.X509CRLEntry;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;
import java.util.Vector;
import javax.security.auth.x500.X500Principal;

public class X509CRLObjectFX extends X509CRL {
   private CertificateList c;
   private String sigAlgName;
   private byte[] sigAlgParams;
   private boolean isIndirect;
   boolean isInvokeConstructMethod;
   byte[] bsCRL;
   FX509CRL fxCRL;
   HashMap hmCRLs;
   ArrayList vtRevokedCertSN;
   AlgorithmIdentifier signatureAlgorithm;
   AlgorithmIdentifier tbsSignatureAlgorithm;
   Principal issuerDN;
   X500Principal issuerX500Principal;
   Date thisUpdate;
   Date nextUpdate;
   byte[] tbsCertList;
   byte[] signature;
   String sigAlgOID;

   public X509CRLObjectFX(CertificateList c) {
      X509CRLObjectFX var10000 = this;
      X509CRLObjectFX var10001 = this;
      X509CRLObjectFX var10002 = this;
      X509CRLObjectFX var10003 = this;
      X509CRLObjectFX var10004 = this;
      X509CRLObjectFX var10005 = this;
      X509CRLObjectFX var10006 = this;
      X509CRLObjectFX var10007 = this;
      X509CRLObjectFX var10008 = this;
      X509CRLObjectFX var10009 = this;
      X509CRLObjectFX var10010 = this;
      X509CRLObjectFX var10011 = this;
      X509CRLObjectFX var10012 = this;
      super();
      this.isInvokeConstructMethod = false;
      this.bsCRL = null;
      this.fxCRL = null;
      HashMap var2;
      var2 = new HashMap.<init>();
      var10012.hmCRLs = var2;
      var10011.vtRevokedCertSN = null;
      var10010.signatureAlgorithm = null;
      var10009.tbsSignatureAlgorithm = null;
      var10008.issuerDN = null;
      var10007.issuerX500Principal = null;
      var10006.thisUpdate = null;
      var10005.nextUpdate = null;
      var10004.tbsCertList = null;
      var10003.signature = null;
      var10002.sigAlgOID = null;
      var10001.c = c;
      var10000.parseData();
   }

   private void invokeConstructMethod() {
      // $FF: Couldn't be decompiled
   }

   private void parseData() {
      Exception var10000;
      label29: {
         boolean var10001;
         DEREncodable var6;
         try {
            this.sigAlgName = X509SignatureUtil.getSignatureName(this.c.getSignatureAlgorithm());
            var6 = this.c.getSignatureAlgorithm().getParameters();
         } catch (Exception var4) {
            var10000 = var4;
            var10001 = false;
            break label29;
         }

         if (var6 != null) {
            try {
               this.sigAlgParams = ((ASN1Encodable)this.c.getSignatureAlgorithm().getParameters()).getDEREncoded();
            } catch (Exception var3) {
               var10000 = var3;
               var10001 = false;
               break label29;
            }
         } else {
            try {
               this.sigAlgParams = null;
            } catch (Exception var2) {
               var10000 = var2;
               var10001 = false;
               break label29;
            }
         }

         try {
            this.isIndirect = this.isIndirectCRL();
            return;
         } catch (Exception var1) {
            var10000 = var1;
            var10001 = false;
         }
      }

      Exception var5 = var10000;
      throw new CRLException("CRL contents invalid: " + var5);
   }

   public X509CRLObjectFX(byte[] bs) {
      X509CRLObjectFX var10000 = this;
      super();
      this.isInvokeConstructMethod = false;
      this.bsCRL = null;
      this.fxCRL = null;
      this.hmCRLs = new HashMap();
      this.vtRevokedCertSN = null;
      this.signatureAlgorithm = null;
      this.tbsSignatureAlgorithm = null;
      this.issuerDN = null;
      this.issuerX500Principal = null;
      this.thisUpdate = null;
      this.nextUpdate = null;
      this.tbsCertList = null;
      this.signature = null;
      this.sigAlgOID = null;
      this.bsCRL = bs;

      Exception var15;
      label68: {
         FX509CRL var16;
         boolean var10001;
         try {
            var16 = new FX509CRL;
         } catch (Exception var11) {
            var15 = var11;
            var10001 = false;
            break label68;
         }

         FX509CRL var2 = var16;

         X509CRLObjectFX var10002;
         FX509CRL var10003;
         X509CRLObjectFX var10004;
         byte[] var10005;
         FX509CRL var10006;
         byte[] var10007;
         byte[] var10008;
         try {
            var10002 = this;
            var10003 = var2;
            var10004 = this;
            var10005 = bs;
            var10006 = var2;
            var10007 = bs;
            var10008 = bs;
            var2.<init>();
         } catch (Exception var10) {
            var15 = var10;
            var10001 = false;
            break label68;
         }

         byte var13 = 0;

         Vector var18;
         try {
            var10006.parse(var10007, var13, var10008.length);
            var10004.bsCRL = var10005;
            var10002.fxCRL = var10003;
            var18 = var16.getRevokedCertificateSNs();
         } catch (Exception var9) {
            var15 = var9;
            var10001 = false;
            break label68;
         }

         Vector var14 = var18;

         try {
            var10000.vtRevokedCertSN = new ArrayList(var14.size());
         } catch (Exception var8) {
            var15 = var8;
            var10001 = false;
            break label68;
         }

         int var3 = 0;

         while(true) {
            int var17;
            int var19;
            try {
               var17 = var3;
               var19 = var14.size();
            } catch (Exception var7) {
               var15 = var7;
               var10001 = false;
               break;
            }

            if (var17 >= var19) {
               return;
            }

            byte[] var20;
            try {
               var10000 = this;
               var20 = DerUtil.copyByteArray(bs, (Item)var14.get(var3));
            } catch (Exception var6) {
               var15 = var6;
               var10001 = false;
               break;
            }

            byte[] var4 = var20;

            try {
               var10000.vtRevokedCertSN.add(new BigInteger(var4));
            } catch (Exception var5) {
               var15 = var5;
               var10001 = false;
               break;
            }

            ++var3;
         }
      }

      Exception var12 = var15;
      throw new CRLException("CRL contents invalid: " + var12);
   }

   private CertificateList getCertificateList() {
      this.invokeConstructMethod();
      CertificateList var1;
      if ((var1 = this.c) != null) {
         return var1;
      } else if (this.bsCRL != null) {
         X509CRLObjectFX var10000;
         boolean var10001;
         CertificateList var5;
         try {
            var10000 = this;
            var5 = CertificateList.getInstance((new ASN1InputStream(new ByteArrayInputStream(this.bsCRL))).readObject());
         } catch (IOException var4) {
            var10001 = false;
            return null;
         }

         var1 = var5;

         try {
            var10000.parseData();
         } catch (Exception var2) {
         }

         try {
            this.c = var1;
            return var1;
         } catch (IOException var3) {
            var10001 = false;
            return null;
         }
      } else {
         return null;
      }
   }

   private Set getExtensionOIDs(boolean critical) {
      this.invokeConstructMethod();
      X509Extensions var5;
      if (this.getVersion() == 2 && (var5 = this.getCertificateList().getTBSCertList().getExtensions()) != null) {
         HashSet var2;
         var2 = new HashSet.<init>();
         Enumeration var3 = var5.oids();

         while(var3.hasMoreElements()) {
            DERObjectIdentifier var4;
            if (critical == var5.getExtension(var4 = (DERObjectIdentifier)var3.nextElement()).isCritical()) {
               var2.add(var4.getId());
            }
         }

         return var2;
      } else {
         return null;
      }
   }

   private Set loadCRLEntries() {
      this.invokeConstructMethod();
      HashSet var1;
      var1 = new HashSet.<init>();
      Enumeration var2 = this.getCertificateList().getRevokedCertificateEnumeration();

      X509CRLEntryObject var10000;
      for(X500Principal var3 = this.getIssuerX500Principal(); var2.hasMoreElements(); var3 = var10000.getCertificateIssuer()) {
         TBSCertList.CRLEntry var4 = (TBSCertList.CRLEntry)var2.nextElement();
         var10000 = new X509CRLEntryObject(var4, this.isIndirect, var3);
         var1.add(var10000);
      }

      return var1;
   }

   private boolean isIndirectCRL() {
      this.invokeConstructMethod();
      byte[] var3;
      byte[] var10000 = var3 = this.getExtensionValue(X509Extensions.IssuingDistributionPoint.getId());
      boolean var1 = false;
      if (var10000 != null) {
         boolean var4;
         try {
            var4 = IssuingDistributionPoint.getInstance(X509ExtensionUtil.fromExtensionValue(var3)).isIndirectCRL();
         } catch (Exception var2) {
            throw new ExtCRLException("Exception reading IssuingDistributionPoint", var2);
         }

         var1 = var4;
      }

      return var1;
   }

   public boolean hasUnsupportedCriticalExtension() {
      this.invokeConstructMethod();
      Set var1;
      if ((var1 = this.getCriticalExtensionOIDs()) == null) {
         return false;
      } else {
         var1.remove(RFC3280CertPathUtilities.ISSUING_DISTRIBUTION_POINT);
         var1.remove(RFC3280CertPathUtilities.DELTA_CRL_INDICATOR);
         return var1.isEmpty() ^ true;
      }
   }

   public Set getCriticalExtensionOIDs() {
      this.invokeConstructMethod();
      return this.getExtensionOIDs(true);
   }

   public Set getNonCriticalExtensionOIDs() {
      this.invokeConstructMethod();
      return this.getExtensionOIDs(false);
   }

   public byte[] getExtensionValue(String oid) {
      this.invokeConstructMethod();
      X509Extensions var3;
      if ((var3 = this.getCertificateList().getTBSCertList().getExtensions()) != null) {
         X509Extensions var10000 = var3;
         DERObjectIdentifier var4;
         var4 = new DERObjectIdentifier.<init>(oid);
         X509Extension var5;
         if ((var5 = var10000.getExtension(var4)) != null) {
            try {
               return var5.getValue().getEncoded();
            } catch (Exception var2) {
               throw new IllegalStateException("error parsing " + var2.toString());
            }
         }
      }

      return null;
   }

   public byte[] getEncoded() {
      byte[] var1;
      if ((var1 = this.bsCRL) != null) {
         return var1;
      } else if (this.fxCRL != null) {
         return var1;
      } else {
         ByteArrayOutputStream var3;
         ByteArrayOutputStream var10000 = var3 = new ByteArrayOutputStream;
         var10000.<init>();
         X509CRLObjectFX var10002 = this;
         DEROutputStream var10001 = new DEROutputStream(var3);

         try {
            var10001.writeObject(var10002.c);
            return var10000.toByteArray();
         } catch (IOException var2) {
            throw new CRLException(var2.toString());
         }
      }
   }

   public void verify(PublicKey key) {
      this.verify(key, "INFOSEC");
   }

   public AlgorithmIdentifier getSignatureAlgorithm() {
      AlgorithmIdentifier var1;
      if ((var1 = this.signatureAlgorithm) != null) {
         return var1;
      } else {
         FX509CRL var3;
         if ((var3 = this.fxCRL) != null) {
            X509CRLObjectFX var10000 = this;
            byte[] var4 = var3.getItemDataAndTag(var3.getSignatureAlgorithm());
            ASN1InputStream var10001 = new ASN1InputStream(new ByteArrayInputStream(var4));

            try {
               var10000.signatureAlgorithm = AlgorithmIdentifier.getInstance(var10001.readObject());
            } catch (IOException var2) {
               throw new RuntimeException(var2.getMessage());
            }
         }

         return this.signatureAlgorithm;
      }
   }

   public AlgorithmIdentifier getTBSSignature() {
      AlgorithmIdentifier var1;
      if ((var1 = this.tbsSignatureAlgorithm) != null) {
         return var1;
      } else {
         FX509CRL var3;
         if ((var3 = this.fxCRL) != null) {
            X509CRLObjectFX var10000 = this;
            byte[] var4 = var3.getItemDataAndTag(var3.getSignature());
            ASN1InputStream var10001 = new ASN1InputStream(new ByteArrayInputStream(var4));

            try {
               var10000.tbsSignatureAlgorithm = AlgorithmIdentifier.getInstance(var10001.readObject());
            } catch (IOException var2) {
               throw new RuntimeException(var2.getMessage());
            }
         }

         return this.tbsSignatureAlgorithm;
      }
   }

   public void verify(PublicKey key, String sigProvider) {
      if (this.fxCRL != null) {
         if (!this.getSignatureAlgorithm().equals(this.getTBSSignature())) {
            throw new CRLException("Signature algorithm on CertificateList does not match TBSCertList.");
         }
      } else if (!this.getCertificateList().getSignatureAlgorithm().equals(this.getCertificateList().getTBSCertList().getSignature())) {
         throw new CRLException("Signature algorithm on CertificateList does not match TBSCertList.");
      }

      Signature sigProvider1;
      Signature var10000 = sigProvider1 = Signature.getInstance(this.getSigAlgName(), sigProvider);
      sigProvider1.initVerify(key);
      sigProvider1.update(this.getTBSCertList());
      if (!var10000.verify(this.getSignature())) {
         throw new SignatureException("CRL does not verify with supplied public key.");
      }
   }

   public int getVersion() {
      this.invokeConstructMethod();
      return this.getCertificateList().getVersion();
   }

   public Principal getIssuerDN() {
      Principal var1;
      if ((var1 = this.issuerDN) != null) {
         return var1;
      } else {
         FX509CRL var5;
         if ((var5 = this.fxCRL) != null) {
            byte[] var6 = var5.getItemDataAndTag(var5.getIssuer());

            IOException var10000;
            label34: {
               boolean var10001;
               X509Principal var7;
               try {
                  var7 = new X509Principal;
               } catch (IOException var3) {
                  var10000 = var3;
                  var10001 = false;
                  break label34;
               }

               X509Principal var8 = var7;

               try {
                  var8.<init>(var6);
                  this.issuerDN = var8;
                  return var7;
               } catch (IOException var2) {
                  var10000 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var10000;
            throw new RuntimeException(var4.getMessage());
         } else {
            return new X509Principal(this.getCertificateList().getIssuer());
         }
      }
   }

   public X500Principal getIssuerX500Principal() {
      X500Principal var1;
      if ((var1 = this.issuerX500Principal) != null) {
         return var1;
      } else {
         FX509CRL var5;
         if ((var5 = this.fxCRL) != null) {
            byte[] var7 = var5.getItemDataAndTag(var5.getIssuer());
            return this.issuerX500Principal = new X500Principal(var7);
         } else {
            ByteArrayOutputStream var10000;
            boolean var10001;
            try {
               var10000 = new ByteArrayOutputStream;
            } catch (IOException var4) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }

            ByteArrayOutputStream var6 = var10000;

            ASN1OutputStream var8;
            try {
               var10000.<init>();
               var8 = new ASN1OutputStream;
            } catch (IOException var3) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }

            ASN1OutputStream var9 = var8;

            try {
               var9.<init>(var6);
               var8.writeObject(this.getCertificateList().getIssuer());
               return new X500Principal(var6.toByteArray());
            } catch (IOException var2) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }
         }
      }
   }

   public Date getThisUpdate() {
      Date var1;
      if ((var1 = this.thisUpdate) != null) {
         return var1;
      } else {
         FX509CRL var5;
         if ((var5 = this.fxCRL) != null) {
            byte[] var6 = var5.getItemDataAndTag(var5.getThisUpdate());
            new ByteArrayInputStream(var6, 0, 11);
            ASN1InputStream var10000 = new ASN1InputStream(new ByteArrayInputStream(var6));

            IOException var7;
            label34: {
               boolean var10001;
               Date var8;
               try {
                  var8 = Time.getInstance(var10000.readObject()).getDate();
               } catch (IOException var3) {
                  var7 = var3;
                  var10001 = false;
                  break label34;
               }

               Date var9 = var8;

               try {
                  this.thisUpdate = var9;
                  return var8;
               } catch (IOException var2) {
                  var7 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var7;
            throw new RuntimeException(var4.getMessage());
         } else {
            return this.getCertificateList().getThisUpdate().getDate();
         }
      }
   }

   public Date getNextUpdate() {
      Date var1;
      if ((var1 = this.nextUpdate) != null) {
         return var1;
      } else {
         FX509CRL var5;
         if ((var5 = this.fxCRL) != null) {
            byte[] var6 = var5.getItemDataAndTag(var5.getNextUpdate());
            ASN1InputStream var10000 = new ASN1InputStream(new ByteArrayInputStream(var6));

            IOException var7;
            label38: {
               boolean var10001;
               Date var8;
               try {
                  var8 = Time.getInstance(var10000.readObject()).getDate();
               } catch (IOException var3) {
                  var7 = var3;
                  var10001 = false;
                  break label38;
               }

               Date var9 = var8;

               try {
                  this.nextUpdate = var9;
                  return var8;
               } catch (IOException var2) {
                  var7 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var7;
            throw new RuntimeException(var4.getMessage());
         } else {
            return this.getCertificateList().getNextUpdate() != null ? this.getCertificateList().getNextUpdate().getDate() : null;
         }
      }
   }

   public X509CRLEntry getRevokedCertificate(BigInteger serialNumber) {
      this.invokeConstructMethod();
      Enumeration var2 = this.getCertificateList().getRevokedCertificateEnumeration();

      X509CRLEntryObject var5;
      for(X500Principal var3 = this.getIssuerX500Principal(); var2.hasMoreElements(); var3 = var5.getCertificateIssuer()) {
         TBSCertList.CRLEntry var4;
         TBSCertList.CRLEntry var10001 = var4 = (TBSCertList.CRLEntry)var2.nextElement();
         var5 = new X509CRLEntryObject.<init>(var4, this.isIndirect, var3);
         if (serialNumber.equals(var10001.getUserCertificate().getValue())) {
            return var5;
         }
      }

      return null;
   }

   public Set getRevokedCertificates() {
      this.invokeConstructMethod();
      Set var1;
      return !(var1 = this.loadCRLEntries()).isEmpty() ? Collections.unmodifiableSet(var1) : null;
   }

   public byte[] getTBSCertList() {
      byte[] var1;
      if ((var1 = this.tbsCertList) != null) {
         return var1;
      } else {
         FX509CRL var3;
         if ((var3 = this.fxCRL) != null) {
            return this.tbsCertList = var3.getItemDataAndTag(var3.getTBSCertList());
         } else {
            try {
               return this.getCertificateList().getTBSCertList().getEncoded("DER");
            } catch (IOException var2) {
               throw new CRLException(var2.toString());
            }
         }
      }
   }

   public byte[] getSignature() {
      byte[] var1;
      if ((var1 = this.signature) != null) {
         return var1;
      } else {
         FX509CRL var4;
         if ((var4 = this.fxCRL) != null) {
            byte[] var2;
            byte[] var10000 = var2 = new byte[(var1 = var4.getItemData(var4.getSignatureValue())).length - 1];
            X509CRLObjectFX var10001 = this;
            int var3 = var1.length - 1;
            System.arraycopy(var1, 1, var2, 0, var3);
            var10001.signature = var2;
            return var10000;
         } else {
            return this.getCertificateList().getSignature().getBytes();
         }
      }
   }

   public String getSigAlgName() {
      String var1;
      if ((var1 = this.sigAlgName) != null) {
         return var1;
      } else {
         if (this.fxCRL != null) {
            this.sigAlgName = X509SignatureUtil.getSignatureName(this.getSignatureAlgorithm());
         }

         return this.sigAlgName;
      }
   }

   public String getSigAlgOID() {
      String var1;
      if ((var1 = this.sigAlgOID) != null) {
         return var1;
      } else {
         FX509CRL var5;
         if ((var5 = this.fxCRL) != null) {
            byte[] var10000 = var5.getItemData(var5.getSignatureAlgorithm());

            IOException var6;
            label34: {
               boolean var10001;
               String var7;
               try {
                  var7 = AlgorithmIdentifier.getInstance(DerUtil.getDerObject(var10000)).getObjectId().getId();
               } catch (IOException var3) {
                  var6 = var3;
                  var10001 = false;
                  break label34;
               }

               String var8 = var7;

               try {
                  this.sigAlgOID = var8;
                  return var7;
               } catch (IOException var2) {
                  var6 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var6;
            throw new RuntimeException(var4.getMessage());
         } else {
            return this.getCertificateList().getSignatureAlgorithm().getObjectId().getId();
         }
      }
   }

   public byte[] getSigAlgParams() {
      this.invokeConstructMethod();
      byte[] var3;
      if ((var3 = this.sigAlgParams) != null) {
         int var1;
         byte[] var2;
         byte[] var10000 = var2 = new byte[var1 = var3.length];
         System.arraycopy(var3, 0, var2, 0, var1);
         return var10000;
      } else {
         return null;
      }
   }

   public String toString() {
      this.invokeConstructMethod();
      StringBuffer var1;
      StringBuffer var10000 = var1 = new StringBuffer;
      var1.<init>();
      String var2 = System.getProperty("line.separator");
      var1.append("              Version: ").append(this.getVersion()).append(var2);
      var1.append("             IssuerDN: ").append(this.getIssuerDN()).append(var2);
      var1.append("          This update: ").append(this.getThisUpdate()).append(var2);
      var1.append("          Next update: ").append(this.getNextUpdate()).append(var2);
      var1.append("  Signature Algorithm: ").append(this.getSigAlgName()).append(var2);
      byte[] var3 = this.getSignature();
      var10000.append("            Signature: ").append(new String(Hex.encode(var3, 0, 20))).append(var2);

      for(int var4 = 20; var4 < var3.length; var4 += 20) {
         if (var4 < var3.length - 20) {
            var1.append("                       ").append(new String(Hex.encode(var3, var4, 20))).append(var2);
         } else {
            var1.append("                       ").append(new String(Hex.encode(var3, var4, var3.length - var4))).append(var2);
         }
      }

      X509Extensions var23;
      if ((var23 = this.getCertificateList().getTBSCertList().getExtensions()) != null) {
         Enumeration var24;
         if ((var24 = var23.oids()).hasMoreElements()) {
            var1.append("           Extensions: ").append(var2);
         }

         label125:
         while(true) {
            while(true) {
               while(true) {
                  if (!var24.hasMoreElements()) {
                     break label125;
                  }

                  DERObjectIdentifier var5;
                  X509Extension var6;
                  if ((var6 = var23.getExtension(var5 = (DERObjectIdentifier)var24.nextElement())).getValue() != null) {
                     DERObjectIdentifier var25 = var5;
                     byte[] var7 = var6.getValue().getOctets();
                     ASN1InputStream var8;
                     var8 = new ASN1InputStream.<init>(var7);
                     var1.append("                       critical(").append(var6.isCritical()).append(") ");

                     label120: {
                        boolean var10001;
                        boolean var26;
                        try {
                           var26 = var25.equals(X509Extensions.CRLNumber);
                        } catch (Exception var20) {
                           var10001 = false;
                           break label120;
                        }

                        if (var26) {
                           try {
                              var1.append(new CRLNumber(DERInteger.getInstance(var8.readObject()).getPositiveValue())).append(var2);
                              continue;
                           } catch (Exception var9) {
                              var10001 = false;
                           }
                        } else {
                           label116: {
                              try {
                                 var26 = var5.equals(X509Extensions.DeltaCRLIndicator);
                              } catch (Exception var19) {
                                 var10001 = false;
                                 break label116;
                              }

                              if (var26) {
                                 try {
                                    var1.append("Base CRL: " + new CRLNumber(DERInteger.getInstance(var8.readObject()).getPositiveValue())).append(var2);
                                    continue;
                                 } catch (Exception var10) {
                                    var10001 = false;
                                 }
                              } else {
                                 label112: {
                                    try {
                                       var26 = var5.equals(X509Extensions.IssuingDistributionPoint);
                                    } catch (Exception var18) {
                                       var10001 = false;
                                       break label112;
                                    }

                                    if (var26) {
                                       try {
                                          var1.append(new IssuingDistributionPoint((ASN1Sequence)var8.readObject())).append(var2);
                                          continue;
                                       } catch (Exception var11) {
                                          var10001 = false;
                                       }
                                    } else {
                                       label108: {
                                          try {
                                             var26 = var5.equals(X509Extensions.CRLDistributionPoints);
                                          } catch (Exception var17) {
                                             var10001 = false;
                                             break label108;
                                          }

                                          if (var26) {
                                             try {
                                                var1.append(new CRLDistPoint((ASN1Sequence)var8.readObject())).append(var2);
                                                continue;
                                             } catch (Exception var12) {
                                                var10001 = false;
                                             }
                                          } else {
                                             label104: {
                                                try {
                                                   var26 = var5.equals(X509Extensions.FreshestCRL);
                                                } catch (Exception var16) {
                                                   var10001 = false;
                                                   break label104;
                                                }

                                                if (var26) {
                                                   try {
                                                      var1.append(new CRLDistPoint((ASN1Sequence)var8.readObject())).append(var2);
                                                      continue;
                                                   } catch (Exception var13) {
                                                      var10001 = false;
                                                   }
                                                } else {
                                                   label139: {
                                                      try {
                                                         var10000 = var1;
                                                         var1.append(var5.getId());
                                                      } catch (Exception var15) {
                                                         var10001 = false;
                                                         break label139;
                                                      }

                                                      try {
                                                         var10000.append(" value = ").append(ASN1Dump.dumpAsString(var8.readObject())).append(var2);
                                                         continue;
                                                      } catch (Exception var14) {
                                                         var10001 = false;
                                                      }
                                                   }
                                                }
                                             }
                                          }
                                       }
                                    }
                                 }
                              }
                           }
                        }
                     }

                     var1.append(var5.getId());
                     var1.append(" value = ").append("*****").append(var2);
                  } else {
                     var1.append(var2);
                  }
               }
            }
         }
      }

      Set var21;
      if ((var21 = this.getRevokedCertificates()) != null) {
         Iterator var22 = var21.iterator();

         while(var22.hasNext()) {
            var1.append(var22.next());
            var1.append(var2);
         }
      }

      return var1.toString();
   }

   public boolean isRevoked(Certificate cert) {
      if (!cert.getType().equals("X.509")) {
         throw new RuntimeException("X.509 CRL used with non X.509 Cert");
      } else {
         TBSCertList.CRLEntry[] var2;
         if ((var2 = this.getCertificateList().getRevokedCertificates()) != null) {
            BigInteger cert1 = ((X509Certificate)cert).getSerialNumber();

            for(int var3 = 0; var3 < var2.length; ++var3) {
               ArrayList var4;
               if ((var4 = this.vtRevokedCertSN) != null) {
                  if (var4.contains(cert1)) {
                     return true;
                  }
               } else if (var2[var3].getUserCertificate().getValue().equals(cert1)) {
                  return true;
               }
            }
         }

         return false;
      }
   }
}
